pub struct CsvSource { /* private fields */ }Expand description
A Config for CsvOpener
Example: create a DataSourceExec for CSV
let options = CsvOptions {
has_header: Some(true),
delimiter: b',',
quote: b'"',
newlines_in_values: Some(true), // The file contains newlines in values
..Default::default()
};
let source = Arc::new(CsvSource::new(file_schema.clone())
.with_csv_options(options)
.with_terminator(Some(b'#'))
);
// Create a DataSourceExec for reading the first 100MB of `file1.csv`
let config = FileScanConfigBuilder::new(object_store_url, source)
.with_file(PartitionedFile::new("file1.csv", 100*1024*1024))
.build();
let exec = (DataSourceExec::from_data_source(config));Implementations
Sourceimpl CsvSource
impl CsvSource
Sourcepub fn new(table_schema: impl Into<TableSchema>) -> Self
pub fn new(table_schema: impl Into<TableSchema>) -> Self
Returns a CsvSource
Sourcepub fn with_csv_options(self, options: CsvOptions) -> Self
pub fn with_csv_options(self, options: CsvOptions) -> Self
Sets the CSV options
Sourcepub fn has_header(&self) -> bool
pub fn has_header(&self) -> bool
true if the first line of each file is a header
pub fn truncate_rows(&self) -> bool
Sourcepub fn terminator(&self) -> Option<u8>
pub fn terminator(&self) -> Option<u8>
The line terminator
Sourcepub fn with_escape(&self, escape: Option<u8>) -> Self
pub fn with_escape(&self, escape: Option<u8>) -> Self
Initialize a CsvSource with escape
Sourcepub fn with_terminator(&self, terminator: Option<u8>) -> Self
pub fn with_terminator(&self, terminator: Option<u8>) -> Self
Initialize a CsvSource with terminator
Sourcepub fn with_comment(&self, comment: Option<u8>) -> Self
pub fn with_comment(&self, comment: Option<u8>) -> Self
Initialize a CsvSource with comment
Sourcepub fn with_truncate_rows(&self, truncate_rows: bool) -> Self
pub fn with_truncate_rows(&self, truncate_rows: bool) -> Self
Whether to support truncate rows when read csv file
Sourcepub fn newlines_in_values(&self) -> bool
pub fn newlines_in_values(&self) -> bool
Whether values may contain newline characters
Sourceimpl CsvSource
impl CsvSource
Sourcepub fn try_from_proto(
node: &PhysicalPlanNode,
ctx: &ExecutionPlanDecodeCtx<'_>,
) -> Result<Arc<dyn ExecutionPlan>>
pub fn try_from_proto( node: &PhysicalPlanNode, ctx: &ExecutionPlanDecodeCtx<'_>, ) -> Result<Arc<dyn ExecutionPlan>>
Reconstructs a DataSourceExec from a protobuf CsvScan.
Custom line terminators are not represented in the wire format.